import { assert } from "@code-like-a-carpenter/assert";
import { getCurrentSpan } from "@code-like-a-carpenter/telemetry";
import { CDCHandler } from "../common/cdc-handler";
import { makeSqsHandler } from "../common/handlers";
function makeReactor(constructor, sdk, dependencies) {
  const reactor = new constructor(sdk);
  return makeSqsHandler(async (record) => {
    await reactor.react(record);
  }, dependencies);
}
class Reactor extends CDCHandler {
  sdk;
  constructor(sdk) {
    super();
    this.sdk = sdk;
  }
  react(unmarshalledRecord) {
    return this.runWithNewSpan("react", async () => {
      const { unmarshallSourceModel } = this.sdk;
      assert(
        unmarshalledRecord.dynamodb?.NewImage,
        "NewImage missing from DynamoDB Stream Event. This should never happen."
      );
      const source = unmarshallSourceModel(
        unmarshalledRecord.dynamodb?.NewImage
      );
      const previous = unmarshalledRecord.dynamodb?.OldImage && unmarshallSourceModel(unmarshalledRecord.dynamodb.OldImage);
      getCurrentSpan()?.setAttributes({
        "com.code-like-a-carpenter.foundation.previous.exists": !!previous
      });
      return this.runWithNewSpan("handle", () => this.handle(source, previous));
    });
  }
}
export {
  Reactor,
  makeReactor
};
